# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Link para o curso [PythonPro] (https://www.python.pro.br)

[![Build Status](https://app.travis-ci.com/igorsantos8888/libpythonpro.svg?branch=main)](https://app.travis-ci.com/igorsantos8888/libpythonpro)

Suportada versão 3 do Python

Para instalar:
```
console: 
python -m venv venv
venv/Scripts/activate
pip install -r requirements-dev.txt
```

Para conferir a qualidade do código:
````
commandline
flake8
````

tópicos a serem abordados:

1. Git
2. Virtualenv
3. Pip